@@ -23,9 +23,19 @@ class ReorderHostRequestDto(BaseModel):
     hosts: List[ReorderHostItem]
 
 
+class HostInboundData(BaseModel):
+    config_profile_uuid: Optional[UUID] = Field(alias="configProfileUuid")
+    config_profile_inbound_uuid: Optional[UUID] = Field(alias="configProfileInboundUuid")
+
+
+class CreateHostInboundData(BaseModel):
+    config_profile_uuid: UUID = Field(serialization_alias="configProfileUuid")
+    config_profile_inbound_uuid: UUID = Field(serialization_alias="configProfileInboundUuid")
+
+
 class UpdateHostRequestDto(BaseModel):
     uuid: UUID
-    inbound_uuid: Optional[UUID] = Field(None, serialization_alias="inboundUuid")
+    inbound: Optional[CreateHostInboundData] = None
     remark: Annotated[Optional[str], StringConstraints(max_length=40)] = None
     address: Optional[str] = None
     port: Optional[int] = None
@@ -42,17 +52,7 @@ class UpdateHostRequestDto(BaseModel):
     server_description: Optional[str] = Field(
         None, serialization_alias="serverDescription", max_length=30
     )
-    mux_params: Optional[str] = Field(
-        None,
-        serialization_alias="muxParams",
-    )
-    sockopt_params: Optional[str] = Field(
-        None,
-        serialization_alias="sockoptParams",
-    )
-    tag: Optional[Annotated[str, StringConstraints(max_length=32)]] = Field(
-        None, serialization_alias="tag"
-    )
+    tag: Optional[Annotated[str, StringConstraints(max_length=32, pattern=r"^[A-Z0-9_:]+$")]] = None
     is_hidden: Optional[bool] = Field(
         None,
         serialization_alias="isHidden",
@@ -79,12 +79,20 @@ class UpdateHostRequestDto(BaseModel):
         None,
         serialization_alias="xHttpExtraParams",
     )
-    nodes: Optional[List[str]] = None
+    mux_params: Optional[str] = Field(
+        None,
+        serialization_alias="muxParams",
+    )
+    sockopt_params: Optional[str] = Field(
+        None,
+        serialization_alias="sockoptParams",
+    )
+    nodes: Optional[List[UUID]] = None
 
-
-class HostInboundData(BaseModel):
-    config_profile_uuid: Optional[UUID] = Field(alias="configProfileUuid")
-    config_profile_inbound_uuid: Optional[UUID] = Field(alias="configProfileInboundUuid")
+    # Legacy compatibility properties
+    @property
+    def inbound_uuid(self) -> Optional[UUID]:
+        return self.inbound.config_profile_inbound_uuid if self.inbound else None
 
 
 class HostResponseDto(BaseModel):
@@ -121,7 +129,7 @@ class HostResponseDto(BaseModel):
     )
     shuffle_host: bool = Field(alias="shuffleHost")
     mihomo_x25519: bool = Field(alias="mihomoX25519")
-    nodes: List[str]
+    nodes: List[UUID]
     is_disabled: bool = Field(
         default=False,
         alias="isDisabled",
@@ -149,54 +157,9 @@ class HostResponseDto(BaseModel):
         return self.inbound.config_profile_inbound_uuid
 
 
-class HostsResponseDto(List[HostResponseDto]):
-    pass
-
-
-class CreateHostResponseDto(HostResponseDto):
-    pass
-
-
-class UpdateHostResponseDto(HostResponseDto):
-    pass
-
-
-class GetAllHostTagsResponseDto(BaseModel):
-    tags: list[str] = None
-
-
-class GetAllHostsResponseDto(RootModel[List[HostResponseDto]]):
-    root: List[HostResponseDto]
-
-    def __iter__(self):
-        return iter(self.root)
-
-    def __getitem__(self, item):
-        return self.root[item]
-
-
-class GetOneHostResponseDto(HostResponseDto):
-    pass
-
-
-class ReorderHostResponseDto(BaseModel):
-    is_updated: bool = Field(alias="isUpdated", default=True)
-
-
-class DeleteHostResponseDto(BaseModel):
-    is_deleted: bool = Field(alias="isDeleted")
-
-
-class CreateHostInboundData(BaseModel):
-    config_profile_uuid: Optional[UUID] = Field(serialization_alias="configProfileUuid")
-    config_profile_inbound_uuid: Optional[UUID] = Field(
-        serialization_alias="configProfileInboundUuid"
-    )
-
-
 class CreateHostRequestDto(BaseModel):
     inbound: CreateHostInboundData
-    remark: Annotated[str, StringConstraints(max_length=40)]
+    remark: Annotated[str, StringConstraints(min_length=1, max_length=40)]
     address: str
     port: int
     path: Optional[str] = None
@@ -219,9 +182,7 @@ class CreateHostRequestDto(BaseModel):
     server_description: Optional[str] = Field(
         None, serialization_alias="serverDescription", max_length=30
     )
-    tag: Optional[Annotated[str, StringConstraints(max_length=32)]] = Field(
-        None, serialization_alias="tag"
-    )
+    tag: Optional[Annotated[str, StringConstraints(max_length=32, pattern=r"^[A-Z0-9_:]+$")]] = None
     vless_route_id: Optional[int] = Field(
         None,
         serialization_alias="vlessRouteId",
@@ -236,7 +197,7 @@ class CreateHostRequestDto(BaseModel):
         False,
         serialization_alias="mihomoX25519",
     )
-    nodes: List[str] = Field(default_factory=list)
+    nodes: List[UUID] = Field(default_factory=list)
     allow_insecure: bool = Field(
         False,
         serialization_alias="allowInsecure",
@@ -278,4 +239,42 @@ class CreateHostRequestDto(BaseModel):
                 or UUID("107541f1-ae1a-4e2d-9dec-7297557b5125"),
                 config_profile_inbound_uuid=inbound_uuid,
             )
-        super().__init__(**data)
\ No newline at end of file
+        super().__init__(**data)
+
+
+class GetAllHostTagsResponseDto(BaseModel):
+    tags: List[str]
+
+
+class CreateHostResponseDto(HostResponseDto):
+    pass
+
+
+class UpdateHostResponseDto(HostResponseDto):
+    pass
+
+
+class GetAllHostsResponseDto(RootModel[List[HostResponseDto]]):
+    root: List[HostResponseDto]
+
+    def __iter__(self):
+        return iter(self.root)
+
+    def __getitem__(self, item):
+        return self.root[item]
+
+
+class GetOneHostResponseDto(HostResponseDto):
+    pass
+
+
+class ReorderHostResponseDto(BaseModel):
+    is_updated: bool = Field(alias="isUpdated", default=True)
+
+
+class DeleteHostResponseDto(BaseModel):
+    is_deleted: bool = Field(alias="isDeleted")
+
+
+# Legacy compatibility
+HostsResponseDto = List[HostResponseDto]
\ No newline at end of file
